@@ -12,7 +12,6 @@
 #include "resourcebase.h"
 
 #include "agentsearchinterface.h"
-#include "searchquery.h"
 #include "xmldocument.h"
 
 #include "settings.h"
@@ -28,9 +27,6 @@ public:
     explicit KnutResource(const QString &id);
     ~KnutResource() override;
 
-public Q_SLOTS:
-    void configure(WId windowId) override;
-
 protected:
     void retrieveCollections() override;
     void retrieveItems(const Akonadi::Collection &collection) override;
