@@ -6,7 +6,6 @@
 
 #include "testsearchplugin.h"
 
-#include "searchquery.h"
 #include <QDebug>
 #include <QVariant>
 
@@ -26,7 +25,7 @@ QSet<qint64> TestSearchPlugin::parseQuery(const QString &queryString)
     const Akonadi::SearchQuery query = Akonadi::SearchQuery::fromJSON(queryString.toLatin1());
     const QList<Akonadi::SearchTerm> subTerms = query.term().subTerms();
     for (const Akonadi::SearchTerm &term : subTerms) {
-        if (term.key() == QLatin1String("plugin")) {
+        if (term.key() == QLatin1StringView("plugin")) {
             resultSet << term.value().toInt();
         }
     }
