@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef IMAPPARSER_TEST_H
-#define IMAPPARSER_TEST_H
+#pragma once
 
 #include <QObject>
 
@@ -35,5 +34,3 @@ private Q_SLOTS:
     void benchParseQuotedString_data();
     void benchParseQuotedString();
 };
-
-#endif
