@@ -6,11 +6,10 @@
  */
 
 #include "aktest.h"
+#include "entities.h"
 #include "fakeakonadiserver.h"
 #include "handler/searchhelper.h"
 
-#include <entities.h>
-
 #include <QTest>
 
 using namespace Akonadi::Server;
