@@ -9,7 +9,7 @@
 #include "agentmanager.h"
 #include "akonadicontrol_debug.h"
 
-#include <private/dbus_p.h>
+#include "private/dbus_p.h"
 
 #include <QDBusConnection>
 #include <QTimer>
