@@ -6,6 +6,7 @@
 
 #include "attributefactory.h"
 
+#include "collectionannotationsattribute.h"
 #include "collectionidentificationattribute.h"
 #include "collectionquotaattribute.h"
 #include "collectionrightsattribute_p.h"
@@ -90,6 +91,7 @@ public:
             AttributeFactory::registerAttribute<TagAttribute>();
             AttributeFactory::registerAttribute<FavoriteCollectionAttribute>();
             AttributeFactory::registerAttribute<CollectionIdentificationAttribute>();
+            AttributeFactory::registerAttribute<CollectionAnnotationsAttribute>();
         }
     }
     bool initialized = false;
