@@ -13,7 +13,6 @@
 #include "exceptionbase.h"
 #include "itempayloadinternals_p.h"
 #include "job.h"
-#include "relation.h"
 #include "tag.h"
 
 #include <QByteArray>
@@ -394,13 +393,6 @@ public:
 
     void clearTags();
 
-    /**
-     * Returns all relations of this item.
-     * @since 4.15
-     * @see RelationCreateJob, RelationDeleteJob to modify relations
-     */
-    Relation::List relations() const;
-
     /**
      * Sets the payload based on the canonical representation normally
      * used for data of this mime type.
