@@ -12,14 +12,11 @@
 using namespace Akonadi;
 
 ItemMonitor::ItemMonitor()
-    : d(new Private(this))
+    : d(new ItemMonitorPrivate(this))
 {
 }
 
-ItemMonitor::~ItemMonitor()
-{
-    delete d;
-}
+ItemMonitor::~ItemMonitor() = default;
 
 void ItemMonitor::setItem(const Item &item)
 {
@@ -42,7 +39,7 @@ void ItemMonitor::setItem(const Item &item)
     auto job = new ItemFetchJob(d->mItem);
     job->setFetchScope(fetchScope());
 
-    d->connect(job, &ItemFetchJob::result, d, [this](KJob *job) {
+    d->connect(job, &ItemFetchJob::result, d.get(), [this](KJob *job) {
         d->initialFetchDone(job);
     });
 }
