@@ -6,6 +6,7 @@
 
 #include "itemfetchjob.h"
 
+#include "akonadicore_debug.h"
 #include "attributefactory.h"
 #include "collection.h"
 #include "itemfetchscope.h"
@@ -17,10 +18,14 @@
 
 #include <QTimer>
 
+#include <span>
+
 using namespace Akonadi;
 
 class Akonadi::ItemFetchJobPrivate : public JobPrivate
 {
+    static constexpr std::size_t MaxBatchSize = 10'000UL;
+
 public:
     explicit ItemFetchJobPrivate(ItemFetchJob *parent)
         : JobPrivate(parent)
@@ -41,6 +46,7 @@ public:
             timeout();
         });
     }
+
     void aboutToFinish() override
     {
         timeout();
@@ -59,6 +65,42 @@ public:
         }
     }
 
+    bool requestBatch()
+    {
+        if (!mRequestedItems.empty()) {
+            // If there are more items to fetch, but we already received the LIMIT number of items,
+            // we are technically done...
+            if (mItemsLimit.limit() > -1 && mCount >= mItemsLimit.limit()) {
+                return true;
+            }
+
+            const auto batchSize = qMin(MaxBatchSize, mRemainingItems.size());
+            if (batchSize == 0) {
+                // If we would fetch an empty batch, we are done.
+                return true;
+            }
+
+            const auto batch = mRemainingItems.subspan(0, batchSize);
+            mRemainingItems = mRemainingItems.subspan(batch.size());
+            const auto batchItems = QList(batch.begin(), batch.end());
+            sendCommand(Protocol::FetchItemsCommandPtr::create(ProtocolHelper::entitySetToScope(batchItems),
+                                                               ProtocolHelper::commandContextToProtocol(mCollection, mCurrentTag, batchItems),
+                                                               ProtocolHelper::itemFetchScopeToProtocol(mFetchScope),
+                                                               ProtocolHelper::tagFetchScopeToProtocol(mFetchScope.tagFetchScope()),
+                                                               mItemsLimit));
+
+        } else { // collection- or tag-based fetch (unbatched)
+            Q_ASSERT(mCount == 0); // can only be called once
+            sendCommand(Protocol::FetchItemsCommandPtr::create(Scope(),
+                                                               ProtocolHelper::commandContextToProtocol(mCollection, mCurrentTag, mRequestedItems),
+                                                               ProtocolHelper::itemFetchScopeToProtocol(mFetchScope),
+                                                               ProtocolHelper::tagFetchScopeToProtocol(mFetchScope.tagFetchScope()),
+                                                               mItemsLimit));
+        }
+
+        return false;
+    }
+
     QString jobDebuggingString() const override
     {
         if (mRequestedItems.isEmpty()) {
@@ -68,9 +110,6 @@ public:
             }
             return str;
 
-        } else if (mRequestedItems.size() > 10) {
-            return QStringLiteral("%1 items from collection %2").arg(mRequestedItems.size()).arg(mCollection.id());
-
         } else {
             try {
                 QString itemStr = QStringLiteral("items id: ");
@@ -88,7 +127,6 @@ public:
                     }
                 }
                 return itemStr;
-
             } catch (const Exception &e) {
                 return QString::fromUtf8(e.what());
             }
@@ -106,9 +144,9 @@ public:
     QTimer mEmitTimer;
     ProtocolHelperValuePool *mValuePool = nullptr;
     ItemFetchJob::DeliveryOptions mDeliveryOptions = ItemFetchJob::Default;
-    int mChunkStart = 0; // index into mRequestedItems
     int mCount = 0;
     Protocol::FetchLimit mItemsLimit;
+    std::span<const Item> mRemainingItems;
 };
 
 ItemFetchJob::ItemFetchJob(const Collection &collection, QObject *parent)
@@ -166,16 +204,9 @@ void ItemFetchJob::doStart()
 {
     Q_D(ItemFetchJob);
 
-    constexpr int maximumParametersSize = 1000;
-    const auto items = d->mRequestedItems.mid(d->mChunkStart, maximumParametersSize);
-    d->mChunkStart += maximumParametersSize;
-
     try {
-        d->sendCommand(Protocol::FetchItemsCommandPtr::create(items.isEmpty() ? Scope() : ProtocolHelper::entitySetToScope(items),
-                                                              ProtocolHelper::commandContextToProtocol(d->mCollection, d->mCurrentTag, items),
-                                                              ProtocolHelper::itemFetchScopeToProtocol(d->mFetchScope),
-                                                              ProtocolHelper::tagFetchScopeToProtocol(d->mFetchScope.tagFetchScope()),
-                                                              d->mItemsLimit));
+        d->mRemainingItems = std::span(d->mRequestedItems.begin(), d->mRequestedItems.size());
+        d->requestBatch();
     } catch (const Akonadi::Exception &e) {
         setError(Job::Unknown);
         setErrorText(QString::fromUtf8(e.what()));
@@ -195,14 +226,10 @@ bool ItemFetchJob::doHandleResponse(qint64 tag, const Protocol::CommandPtr &resp
     const auto &resp = Protocol::cmdCast<Protocol::FetchItemsResponse>(response);
     // Invalid ID marks the last part of the response
     if (resp.id() < 0) {
-        // Do we have more chunks to fetch?
-        if (d->mChunkStart < d->mRequestedItems.size()) {
-            doStart();
-            return false;
+        if (d->mRemainingItems.empty()) {
+            return true;
         }
-
-        // all done
-        return true;
+        return d->requestBatch();
     }
 
     const Item item = ProtocolHelper::parseItemFetchResult(resp, nullptr, d->mValuePool);
