@@ -22,6 +22,8 @@
 
 #include <QFile>
 
+#include <span>
+
 using namespace Akonadi;
 
 ItemModifyJobPrivate::ItemModifyJobPrivate(ItemModifyJob *parent)
@@ -86,6 +88,7 @@ void ItemModifyJobPrivate::doUpdateItemRevision(Akonadi::Item::Id itemId, int ol
 QString ItemModifyJobPrivate::jobDebuggingString() const
 {
     try {
+        mRemainingItems = std::span(mItems);
         return Protocol::debugString(fullCommand());
     } catch (const Exception &e) {
         return QString::fromUtf8(e.what());
@@ -97,6 +100,33 @@ void ItemModifyJobPrivate::setSilent(bool silent)
     mSilent = silent;
 }
 
+bool ItemModifyJobPrivate::nextBatch()
+{
+    Q_Q(ItemModifyJob);
+
+    if (mRemainingItems.empty()) {
+        return true;
+    }
+
+    Protocol::ModifyItemsCommandPtr command;
+    try {
+        command = fullCommand();
+    } catch (const Exception &e) {
+        q->setError(Job::Unknown);
+        q->setErrorText(QString::fromUtf8(e.what()));
+        q->emitResult();
+        return true;
+    }
+
+    if (command->modifiedParts() == Protocol::ModifyItemsCommand::None) {
+        q->emitResult();
+        return true;
+    }
+
+    sendCommand(command);
+    return false;
+}
+
 ItemModifyJob::ItemModifyJob(const Item &item, QObject *parent)
     : Job(new ItemModifyJobPrivate(this), parent)
 {
@@ -131,15 +161,13 @@ ItemModifyJob::ItemModifyJob(const Akonadi::Item::List &items, QObject *parent)
     }
 }
 
-ItemModifyJob::~ItemModifyJob()
-{
-}
+ItemModifyJob::~ItemModifyJob() = default;
 
 Protocol::ModifyItemsCommandPtr ItemModifyJobPrivate::fullCommand() const
 {
     auto cmd = Protocol::ModifyItemsCommandPtr::create();
 
-    const Akonadi::Item item = mItems.first();
+    const Akonadi::Item &item = mRemainingItems.front();
     for (int op : std::as_const(mOperations)) {
         switch (op) {
         case ItemModifyJobPrivate::RemoteId:
@@ -229,7 +257,11 @@ Protocol::ModifyItemsCommandPtr ItemModifyJobPrivate::fullCommand() const
         return cmd;
     }
 
-    cmd->setItems(ProtocolHelper::entitySetToScope(mItems));
+    const auto batchSize = qMin(MaxBatchSize, mRemainingItems.size());
+    const auto batch = mRemainingItems.subspan(0, batchSize);
+    mRemainingItems = mRemainingItems.subspan(batch.size());
+
+    cmd->setItems(ProtocolHelper::entitySetToScope(QList(batch.begin(), batch.end())));
     if (mRevCheck && item.revision() >= 0) {
         cmd->setOldRevision(item.revision());
     }
@@ -245,22 +277,8 @@ void ItemModifyJob::doStart()
 {
     Q_D(ItemModifyJob);
 
-    Protocol::ModifyItemsCommandPtr command;
-    try {
-        command = d->fullCommand();
-    } catch (const Exception &e) {
-        setError(Job::Unknown);
-        setErrorText(QString::fromUtf8(e.what()));
-        emitResult();
-        return;
-    }
-
-    if (command->modifiedParts() == Protocol::ModifyItemsCommand::None) {
-        emitResult();
-        return;
-    }
-
-    d->sendCommand(command);
+    d->mRemainingItems = std::span(d->mItems);
+    d->nextBatch();
 }
 
 bool ItemModifyJob::doHandleResponse(qint64 tag, const Protocol::CommandPtr &response)
@@ -333,6 +351,12 @@ bool ItemModifyJob::doHandleResponse(qint64 tag, const Protocol::CommandPtr &res
             return false;
         }
 
+        if (!d->mRemainingItems.empty()) {
+            if (!d->nextBatch()) {
+                return false;
+            }
+        }
+
         for (const Item &item : std::as_const(d->mItems)) {
             ChangeMediator::invalidateItem(item);
         }
