@@ -9,6 +9,7 @@
 #include "akonadicore_export.h"
 #include "item.h"
 #include "job.h"
+#include "private/protocol_p.h"
 
 namespace Akonadi
 {
@@ -74,8 +75,8 @@ protected:
 
 private:
     Q_DECLARE_PRIVATE(LinkJob)
-    template<typename T> friend class LinkJobImpl;
+    template<typename T, Protocol::LinkItemsCommand::Action>
+    friend class LinkJobImpl;
 };
 
 }
-
