@@ -9,16 +9,12 @@
 #include "entitydeletedattribute.h"
 #include "job_p.h"
 
-#include "trashsettings.h"
-
 #include <KLocalizedString>
 
-#include "collectiondeletejob.h"
 #include "collectionfetchjob.h"
 #include "collectionfetchscope.h"
 #include "collectionmodifyjob.h"
 #include "collectionmovejob.h"
-#include "itemdeletejob.h"
 #include "itemfetchjob.h"
 #include "itemfetchscope.h"
 #include "itemmodifyjob.h"
@@ -247,11 +243,7 @@ void TrashRestoreJobPrivate::collectionsReceived(const Akonadi::Collection::List
 void TrashRestoreJobPrivate::removeAttribute(const Akonadi::Collection::List &list)
 {
     Q_Q(TrashRestoreJob);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QVectorIterator<Collection> i(list);
-#else
     QListIterator<Collection> i(list);
-#endif
     while (i.hasNext()) {
         Collection col = i.next();
         col.removeAttribute<EntityDeletedAttribute>();
@@ -276,11 +268,7 @@ void TrashRestoreJobPrivate::removeAttribute(const Akonadi::Item::List &list)
 {
     Q_Q(TrashRestoreJob);
     Item::List items = list;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QMutableVectorIterator<Item> i(items);
-#else
     QMutableListIterator<Item> i(items);
-#endif
     while (i.hasNext()) {
         Item &item = i.next();
         item.removeAttribute<EntityDeletedAttribute>();
