@@ -450,7 +450,7 @@ bool FavoriteCollectionsModel::dropMimeData(const QMimeData *data, Qt::DropActio
 QStringList FavoriteCollectionsModel::mimeTypes() const
 {
     QStringList mts = KSelectionProxyModel::mimeTypes();
-    if (!mts.contains(QLatin1String("text/uri-list"))) {
+    if (!mts.contains(QLatin1StringView("text/uri-list"))) {
         mts.append(QStringLiteral("text/uri-list"));
     }
     return mts;
