@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SERVERMANAGER_P_H
-#define AKONADI_SERVERMANAGER_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 
@@ -18,11 +17,14 @@ AKONADICORE_EXPORT void setServerProtocolVersion(int version);
 AKONADICORE_EXPORT uint generation();
 AKONADICORE_EXPORT void setGeneration(uint generation);
 
-enum ClientType { User, Agent, Resource };
+enum ClientType {
+    User,
+    Agent,
+    Resource,
+};
 AKONADICORE_EXPORT ClientType clientType();
 AKONADICORE_EXPORT void setClientType(ClientType type);
 
 }
 
 }
-#endif
