@@ -34,7 +34,7 @@ bool ItemFetchHandler::parseStream()
 
     CacheCleanerInhibitor inhibitor(akonadi());
 
-    ItemFetchHelper fetchHelper(connection(), context, cmd.scope(), cmd.itemFetchScope(), cmd.tagFetchScope(), akonadi());
+    ItemFetchHelper fetchHelper(connection(), context, cmd.scope(), cmd.itemFetchScope(), cmd.tagFetchScope(), akonadi(), cmd.itemsLimit());
     if (!fetchHelper.fetchItems()) {
         return failureResponse(QStringLiteral("Failed to fetch items"));
     }
