@@ -549,19 +549,6 @@ bool NotificationSubscriber::acceptsTagNotification(const Protocol::TagChangeNot
     return true;
 }
 
-bool NotificationSubscriber::acceptsRelationNotification(const Protocol::RelationChangeNotification &msg) const
-{
-    // Assumes mLock being locked by caller
-
-    Q_UNUSED(msg)
-
-    if (mAllMonitored) {
-        return true;
-    }
-
-    return !(!mMonitoredTypes.isEmpty() && !mMonitoredTypes.contains(Protocol::ModifySubscriptionCommand::RelationChanges));
-}
-
 bool NotificationSubscriber::acceptsSubscriptionNotification(const Protocol::SubscriptionChangeNotification &msg) const
 {
     // Assumes mLock being locked by caller
@@ -611,8 +598,6 @@ bool NotificationSubscriber::acceptsNotification(const Protocol::ChangeNotificat
         return acceptsCollectionNotification(static_cast<const Protocol::CollectionChangeNotification &>(msg));
     case Protocol::Command::TagChangeNotification:
         return acceptsTagNotification(static_cast<const Protocol::TagChangeNotification &>(msg));
-    case Protocol::Command::RelationChangeNotification:
-        return acceptsRelationNotification(static_cast<const Protocol::RelationChangeNotification &>(msg));
     case Protocol::Command::SubscriptionChangeNotification:
         return acceptsSubscriptionNotification(static_cast<const Protocol::SubscriptionChangeNotification &>(msg));
     case Protocol::Command::DebugChangeNotification:
