@@ -16,7 +16,8 @@ namespace Server
 /**
   Helper class for creating and executing database SELECT queries.
 */
-template<typename T> class SelectQueryBuilder : public QueryBuilder
+template<typename T>
+class SelectQueryBuilder : public QueryBuilder
 {
 public:
     /**
