@@ -9,11 +9,9 @@
 #include "collectioncombobox.h"
 
 #include "asyncselectionhandler_p.h"
-#include "collectiondialog.h"
 
 #include "collectionfetchscope.h"
 #include "collectionfilterproxymodel.h"
-#include "collectionutils.h"
 #include "entityrightsfiltermodel.h"
 #include "entitytreemodel.h"
 #include "monitor.h"
@@ -71,6 +69,9 @@ public:
         mParent->connect(mSelectionHandler, &AsyncSelectionHandler::collectionAvailable, mParent, [this](const auto &mi) {
             activated(mi);
         });
+        mParent->connect(mParent, &QComboBox::currentIndexChanged, mParent, [this](const auto &mi) {
+            activated(mi);
+        });
     }
 
     ~CollectionComboBoxPrivate() = default;
