@@ -1,18 +1,7 @@
 /*
- * Copyright (C) %{CURRENT_YEAR} by %{AUTHOR} <%{EMAIL}>
+ * SPDX-FileCopyrightText: %{CURRENT_YEAR} %{AUTHOR} <%{EMAIL}>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "%{APPNAMELC}resource.h"
@@ -114,3 +103,5 @@ void %{APPNAME}Resource::itemRemoved(const Akonadi::Item &item)
 }
 
 AKONADI_RESOURCE_MAIN(%{APPNAME}Resource)
+
+#include "moc_%{APPNAMELC}resource.cpp"
